@@ -3,6 +3,9 @@ from enum import Enum
 
 class SupportedProtocols(Enum):
     """Contains a list of all supported protocols (currently only http and https
+    Value:
+        http : "http"
+        https : "https"
     """
     http = "http"
     https = "https"
